<?php

declare(strict_types = 1);

namespace Drupal\Tests\node\Functional;

use Drupal\Tests\schemadotorg\Functional\SchemaDotOrgBrowserTestBase;

/**
 * Tests Schema.org content model documentation help functionality.
 *
 * @covers schemadotorg_content_model_documentation_help()
 * @group schemadotorg
 */
class SchemaDotOrgContentModelDocumentationHelpTest extends SchemaDotOrgBrowserTestBase {

  // phpcs:disable
  /**
   * Disabled config schema checking until the schema has been fixed.
   *
   * @see https://www.drupal.org/project/epp/issues/3348759
   */
  protected $strictConfigSchema = FALSE;
  // phpcs:enable

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'block',
    'node',
    'help',
    'schemadotorg_content_model_documentation',
  ];

  /**
   * Test content model documentation help link.
   */
  public function testHelpLink(): void {
    global $base_path;

    $asset_session = $this->assertSession();

    $this->drupalLogin($this->rootUser);
    $this->drupalPlaceBlock('help_block');

    // Create Event without the markup.module enabled.
    $this->createSchemaEntity('node', 'Event');

    // Check that the node add form includes a documentation link.
    $this->drupalGet('node/add/event');
    $asset_session->linkExists('Read documentation');
    $asset_session->linkByHrefExists('/admin/structure/types/manage/event/document');

    // Check that the node edit form includes a documentation link.
    $node = $this->drupalCreateNode(['type' => 'event']);
    $this->drupalGet('node/' . $node->id() . '/edit');
    $asset_session->linkExists('Read documentation');
    $asset_session->linkByHrefExists('/admin/structure/types/manage/event/document');

    // Install the markup to create the schema_cm_documentation field.
    \Drupal::service('module_installer')->install(['markup']);

    // Create Place with the markup.module enabled.
    $this->createSchemaEntity('node', 'Place');

    // Check that the node add form includes a documentation field.
    $this->drupalGet('node/add/place');
    $asset_session->responseContains('<p>&lt;p&gt;Entities that have a somewhat fixed, physical extension. &lt;a href=&quot;' . $base_path . 'admin/structure/types/manage/place/document&quot; target=&quot;_blank&quot; hreflang=&quot;en&quot;&gt;Read documentation&lt;/a&gt;&lt;/p&gt;</p>');
    $asset_session->linkByHrefNotExists('/admin/structure/types/manage/place/document');

    // Check that the node edit form includes a documentation field.
    $node = $this->drupalCreateNode(['type' => 'place']);
    $this->drupalGet('node/' . $node->id() . '/edit');
    $asset_session->responseContains('<p>&lt;p&gt;Entities that have a somewhat fixed, physical extension. &lt;a href=&quot;' . $base_path . 'admin/structure/types/manage/place/document&quot; target=&quot;_blank&quot; hreflang=&quot;en&quot;&gt;Read documentation&lt;/a&gt;&lt;/p&gt;</p>');
    $asset_session->linkByHrefNotExists('/admin/structure/types/manage/place/document');
  }

}
